@@ -43,10 +43,10 @@ OC.L10N.register(
     "{user} has set the due date of card {card} to {after}" : "{user} nustatė galutinį kortelės {card} terminą į {after}",
     "You have updated the due date of card {card} to {after}" : "Jūs atnaujinote galutinį kortelės {card} terminą į {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} atnaujino galutinį kortelės {card} terminą į {after}",
-    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} į kortelę {card} pridėjote žymę {label}",
-    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} į kortelę {card} pridėjo žymę {label}",
-    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} iš kortelės {card} pašalinote žymę {label}",
-    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} iš kortelės {card} pašalino žymę {label}",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} į kortelę {card} pridėjote žymą {label}",
+    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} į kortelę {card} pridėjo žymą {label}",
+    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} iš kortelės {card} pašalinote žymą {label}",
+    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} iš kortelės {card} pašalino žymą {label}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Jūs lentoje {board} prie kortelės {card} priskyrėte {assigneduser}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} lentoje {board} prie kortelės {card} priskyrė {assigneduser}",
     "You have moved the card {card} from list {stackBefore} to {stack}" : "Jūs perkėlėte kortelę {card} iš sąrašo {stackBefore} į sąrašą {stack}",
@@ -92,8 +92,8 @@ OC.L10N.register(
     "Path is already shared with this card" : "Kelias jau yra bendrinamas su šia kortele",
     "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
     "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
-    "Card details" : "Išsamiau apie kortelę",
     "Add board" : "Pridėti lentą",
+    "Card details" : "Išsamiau apie kortelę",
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
@@ -103,25 +103,26 @@ OC.L10N.register(
     "Select a list" : "Pasirinkite sąrašą",
     "Move card" : "Perkelti kortelę",
     "Copy card" : "Kopijuoti kortelę",
-    "Select a card" : "Pasirinkti kortelę",
-    "Cancel" : "Atsisakyti",
     "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
     "Link to card" : "Susieti su kortele",
+    "Select a card" : "Pasirinkti kortelę",
+    "Cancel" : "Atsisakyti",
+    "This board is read only" : "Ši lenta yra tik skaitymui",
+    "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
     "File already exists" : "Failas jau yra",
     "A file with the name {filename} already exists." : "Failas, pavadinimu {filename}, jau yra.",
     "Do you want to overwrite it?" : "Ar norite jį perrašyti?",
     "Overwrite file" : "Perrašyti failą",
     "Keep existing file" : "Palikti esamą failą",
-    "This board is read only" : "Ši lenta yra tik skaitymui",
-    "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
     "Add card" : "Pridėti kortelę",
     "Archived cards" : "Archyvuotos kortelės",
     "Add list" : "Pridėti sąrašą",
     "List name" : "Sąrašo pavadinimas",
     "Active filters" : "Aktyvūs filtrai",
     "Apply filter" : "Taikyti filtrą",
-    "Filter by tag" : "Filtruoti pagal žymę",
+    "Filter by tag" : "Filtruoti pagal žymą",
     "Filter by assigned user" : "Filtruoti pagal priskirtą naudotoją",
+    "Open and completed" : "Atidaryta ir atlikta",
     "Open" : "Atverti",
     "Completed" : "Užbaigta",
     "Filter by due date" : "Filtruoti pagal galutinio termino datą",
@@ -140,12 +141,14 @@ OC.L10N.register(
     "Board not found" : "Lenta nerasta",
     "Create a new list to add cards to this board" : "Norėdami pridėti korteles į šią lentą, sukurkite naują sąrašą",
     "Sharing" : "Bendrinimas",
-    "Tags" : "Žymės",
+    "Tags" : "Žymos",
     "Deleted items" : "Ištrinti elementai",
     "Activity" : "Veikla",
     "Deleted lists" : "Ištrinti sąrašai",
     "Undo" : "Atšaukti",
     "Deleted cards" : "Ištrintos kortelės",
+    "Failed to create share with {displayName}" : "Nepavyko sukurti viešinio su {displayName}",
+    "Transfer" : "Persiųsti",
     "No participants found" : "Nerasta jokių dalyvių",
     "Board owner" : "Lentos savininkas",
     "(Group)" : "(Grupė)",
@@ -155,20 +158,20 @@ OC.L10N.register(
     "Can manage" : "Gali tvarkyti",
     "Owner" : "Savininkas",
     "Delete" : "Ištrinti",
-    "Failed to create share with {displayName}" : "Nepavyko sukurti viešinio su {displayName}",
-    "Transfer" : "Persiųsti",
+    "List deleted" : "Sąrašas ištrintas",
     "Archive all cards" : "Archyvuoti visas korteles",
     "Delete list" : "Ištrinti sąrašą",
     "Archive all cards in this list" : "Archyvuoti visas korteles šiame sąraše",
     "Add a new card" : "Pridėti naują kortelę",
     "Card name" : "Kortelės pavadinimas",
-    "List deleted" : "Sąrašas ištrintas",
-    "Edit" : "Taisyti",
-    "Add a new tag" : "Pridėti naują žymę",
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
+    "Edit" : "Taisyti",
+    "Add a new tag" : "Pridėti naują žymą",
     "Board name" : "Lentos pavadinimas",
     "Members" : "Nariai",
     "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
+    "File to share" : "Failas, kurį bendrinti",
+    "Invalid path selected" : "Pasirinktas neteisingas kelias",
     "Upload new files" : "Išsiųsti naujus failus",
     "Share from Files" : "Bendrinti iš failų",
     "Add this attachment" : "Pridėti šį priedą",
@@ -177,23 +180,22 @@ OC.L10N.register(
     "Remove attachment" : "Šalinti priedą",
     "Delete Attachment" : "Ištrinti priedą",
     "Restore Attachment" : "Atkurti priedą",
-    "File to share" : "Failas, kurį bendrinti",
-    "Invalid path selected" : "Pasirinktas neteisingas kelias",
+    "Modified" : "Pakeistas",
+    "Created" : "Sukurta",
+    "The title cannot be empty." : "Pavadinimas negali būti tuščias.",
     "Open in sidebar view" : "Atverti šoninės juostos rodinyje",
     "Open in bigger view" : "Atverti didesniame rodinyje",
     "Attachments" : "Priedai",
     "Comments" : "Komentarai",
-    "Modified" : "Pakeistas",
-    "Created" : "Sukurta",
-    "The title cannot be empty." : "Pavadinimas negali būti tuščias.",
-    "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
     "Failed to load comments" : "Nepavyko įkelti komentarų",
-    "Save" : "Įrašyti",
+    "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
     "The comment cannot be empty." : "Komentaras negali būti tuščias.",
     "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
+    "Save" : "Įrašyti",
+    "Created:" : "Sukurta:",
     "Reply" : "Atsakyti",
     "Update" : "Atnaujinti",
-    "Created:" : "Sukurta:",
+    "Write a description …" : "Parašykite aprašą…",
     "Description" : "Aprašas",
     "(Unsaved)" : "(Neįrašyta)",
     "(Saving…)" : "(Įrašoma…)",
@@ -201,23 +203,25 @@ OC.L10N.register(
     "Edit description" : "Taisyti aprašą",
     "View description" : "Rodyti aprašą",
     "Add Attachment" : "Pridėti priedą",
-    "Write a description …" : "Parašykite aprašą…",
     "Choose attachment" : "Pasirinkite priedą",
+    "Select Date" : "Pasirinkti datą",
+    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
+    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
+    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
     "Set a due date" : "Nustatyti galutinį terminą",
     "Remove due date" : "Šalinti galutinio termino datą",
     "Mark as done" : "Žymėti kaip atliktą",
     "Unarchive card" : "Išarchyvuoti kortelę",
     "Archive card" : "Archyvuoti kortelę",
-    "Select Date" : "Pasirinkti datą",
-    "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
+    "Assign a tag to this card…" : "Priskirti šiai kortelei žymą…",
     "(group)" : "(grupė)",
-    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
     "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
     "Open link" : "Atverti nuorodą",
+    "Card deleted" : "Kortelė ištrinta",
     "Edit title" : "Taisyti pavadinimą",
     "Assign to me" : "Priskirti sau",
     "Delete card" : "Ištrinti kortelę",
-    "Card deleted" : "Kortelė ištrinta",
     "seconds ago" : "prieš keletą sekundžių",
     "Keyboard shortcuts" : "Spartieji klavišai",
     "Keyboard shortcut" : "Spartusis klavišas",
@@ -231,6 +235,12 @@ OC.L10N.register(
     "Use bigger card view" : "Naudoti didesnį kortelių rodinį",
     "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
     "Cancel edit" : "Atsisakyti taisymo",
+    "Board {0} deleted" : "Lenta {0} ištrinta",
+    "All cards" : "Visos kortelės",
+    "Only assigned cards" : "Tik priskirtos kortelės",
+    "No reminder" : "Jokio priminimo",
+    "An error occurred" : "Įvyko klaida",
+    "Delete the board?" : "Ištrinti lentą?",
     "Board details" : "Išsamiau apie lentą",
     "Edit board" : "Taisyti lentą",
     "Clone board" : "Dubliuoti lentą",
@@ -240,15 +250,9 @@ OC.L10N.register(
     "Turn on due date reminders" : "Įjungti priminimus apie galutinio termino datą",
     "Turn off due date reminders" : "Išjungti priminimus apie galutinio termino datą",
     "Due date reminders" : "Priminimai apie galutinio termino datą",
-    "All cards" : "Visos kortelės",
     "Assigned cards" : "Priskirtos kortelės",
     "No notifications" : "Pranešimų nėra",
     "Delete board" : "Ištrinti lentą",
-    "Board {0} deleted" : "Lenta {0} ištrinta",
-    "Only assigned cards" : "Tik priskirtos kortelės",
-    "No reminder" : "Jokio priminimo",
-    "An error occurred" : "Įvyko klaida",
-    "Delete the board?" : "Ištrinti lentą?",
     "Clone cards" : "Dubliuoti korteles",
     "Advanced options" : "Išplėstinės parinktys",
     "Restore archived cards" : "Atkurti archyvuotas korteles",
@@ -257,20 +261,17 @@ OC.L10N.register(
     "Tomorrow" : "Rytoj",
     "No due" : "Be galutinio termino",
     "No results found" : "Nerasta jokių rezultatų",
+    "Due on {date}" : "Galutinis terminas {date}",
     "Click to expand description" : "Spustelėkite norėdami išskleisti aprašą",
     "Click to expand comment" : "Spustelėkite norėdami išskleisti komentarą",
+    "Create card" : "Sukurti kortelę",
     "Create a new card" : "Sukurti naują kortelę",
     "Card title" : "Kortelės pavadinimas",
-    "Create card" : "Sukurti kortelę",
     "Creating the new card …" : "Kuriama nauja kortelė…",
     "Card \"{card}\" was added to \"{board}\"" : "Kortelė „{card}“ buvo pridėta į lentą „{board}“",
     "Open card" : "Atverti kortelę",
     "Close" : "Užverti",
     "New card" : "Nauja kortelė",
-    "Due on {date}" : "Galutinis terminas {date}",
-    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
-    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
     "Create a card" : "Sukurti kortelę",
